Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/typoglycemia/__init__.py | (no function) | 2 | 0 | 0 | 100%
src/typoglycemia/main.py | shuffle | 5 | 0 | 0 | 100%
src/typoglycemia/main.py | make_typoglycemia | 3 | 1 | 0 | 67%
src/typoglycemia/main.py | cli | 7 | 7 | 0 | 0%
src/typoglycemia/main.py | (no function) | 9 | 1 | 0 | 89%
tests/__init__.py | (no function) | 0 | 0 | 0 | 100%
tests/test_main.py | set_seed | 1 | 0 | 0 | 100%
tests/test_main.py | test_shuffle | 1 | 0 | 0 | 100%
tests/test_main.py | test_make_typoglycemia | 1 | 0 | 0 | 100%
tests/test_main.py | test_cli | 3 | 0 | 0 | 100%
tests/test_main.py | (no function) | 12 | 0 | 0 | 100%
Total |  | 44 | 9 | 0 | 80%

No items found using the specified filter.